@@ -68,18 +68,20 @@ connection && {
   Sys.sleep(1L)
   test_equal(1L, d <- daemons(1L, dispatcher = FALSE, asyncdial = FALSE, seed = 1546L))
   test_print(d)
-  me <- mirai(mirai::mirai(), .timeout = 2000L)
-  if (!is_mirai_error(call_mirai(me)$data)) test_true(is_error_value(me$data))
-  if (is_mirai_error(me$data)) test_type("list", me$data$stack.trace)
-  test_true(!is_mirai_interrupt(me$data))
-  test_class("errorValue", me[["data"]])
+  me <- mirai(mirai::mirai(), .timeout = 2000L)[]
+  if (!is_mirai_error(me)) test_true(is_error_value(me))
+  if (is_mirai_error(me)) test_type("list", me$stack.trace)
+  if (is_mirai_error(me)) test_true(length(me$stack.trace) >= 2L)
+  if (is_mirai_error(me)) test_true(all(as.logical(lapply(me$stack.trace, is.character))))
+  test_true(!is_mirai_interrupt(me))
+  test_class("errorValue", me)
   test_print(me)
-  test_print(me$data)
   df <- data.frame(a = 1, b = 2)
   dm <- mirai(as.matrix(df), .args = list(df = df), .timeout = 2000L)
   test_true(is_mirai(call_mirai(dm)))
   test_true(!unresolved(dm))
   if (!is_error_value(dm$data)) test_class("matrix", dm$data)
+  test_print(dm)
   test_type("integer", status()[["connections"]])
   test_type("character", status()[["daemons"]])
   test_type("character", mlc <- launch_remote("ws://[::1]:5555"))
@@ -262,7 +264,6 @@ connection && .Platform[["OS.type"]] != "windows" && Sys.getenv("NOT_CRAN") == "
   test_true(res[[1L]] != res[[2L]])
   test_zero(daemons(0))
   test_equal(1L, daemons(url = "wss://127.0.0.1:0", token = TRUE, pass = "test"))
-  test_type("list", serialization(list(function(x) serialize(x, NULL), unserialize), "tst_cls"))
   test_null(launch_local(1L))
   Sys.sleep(1L)
   test_true(grepl("CERTIFICATE", launch_remote(1L), fixed = TRUE))
@@ -274,7 +275,6 @@ connection && .Platform[["OS.type"]] != "windows" && Sys.getenv("NOT_CRAN") == "
   test_null(saisei(1))
   test_error(launch_local(0:1), "out of bounds")
   test_error(launch_remote(1:2), "out of bounds")
-  test_true(!length(serialization(NULL)))
   option <- 15L
   Sys.setenv(R_DEFAULT_PACKAGES = "stats,utils")
   test_equal(1L, daemons(1, dispatcher = TRUE, maxtasks = 10L, timerstart = 1L, walltime = 1000L, seed = 1546, token = TRUE, cleanup = option, autoexit = tools::SIGCONT))
